| jacobian_vech_Sigma | R Documentation |
Utility to compute analytical Jacobian of random coefficient matrix transformed by vech (dVech(Sigma) / dTheta)
jacobian_vech_Sigma(L_params, K_w, rc_correlation = TRUE)
L_params |
flattened choleski decomposition version of the random coefficient parameters matrix |
K_w |
dimension of the random coefficient parameter (symmetric) matrix |
rc_correlation |
whether random coefficients are correlated |
Jacobian (dVech(Sigma) / dTheta)
L_params <- c(log(0.8), 0.2, log(0.6))
J_mat <- choicer:::jacobian_vech_Sigma(L_params, K_w = 2, rc_correlation = TRUE)
dim(J_mat) # 3 x 3 for K_w=2 correlated
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.