nobs.choicer_hb: Number of choice situations behind a hierarchical Bayes fit

View source: R/methods.R

nobs.choicer_hbR Documentation

Number of choice situations behind a hierarchical Bayes fit

Description

Number of choice situations behind a hierarchical Bayes fit

Usage

## S3 method for class 'choicer_hb'
nobs(object, ...)

Arguments

object

A choicer_hmnl or choicer_hmnp object.

...

Additional arguments (ignored).

Value

Integer count of choice situations (tasks).


choicer documentation built on Sept. 5, 2026, 1:07 a.m.