| build_var_mat | R Documentation |
Reconstruct variance matrix L from L_params
build_var_mat(L_params, K_w, rc_correlation)
L_params |
flattened choleski decomposition version of the random coefficient parameters matrix |
K_w |
dimension of the random coefficient parameter (symmetric) matrix |
rc_correlation |
whether random coefficients are correlated |
matrix equal to LL', where L is the choleski decomposition of random coefficient matrix
L_params <- c(log(1.0), 0.3, log(0.5))
Sigma <- choicer:::build_var_mat(L_params, K_w = 2, rc_correlation = TRUE)
Sigma # 2x2 covariance matrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.